ErrorCodes enum

Error codes that may occur in the service.

Inheritance
Available extensions

Values

ALREADY_STARTED → const ErrorCodes

Occurs when the service has already been started but the start function is called.

LOCATION_SERVICES_DISABLED → const ErrorCodes

Occurs when location services are disabled. When this error occurs, you should notify the user and request activation.

LOCATION_PERMISSION_DENIED → const ErrorCodes

Occurs when location permission is denied.

LOCATION_PERMISSION_PERMANENTLY_DENIED → const ErrorCodes

Occurs when location permission is permanently denied. In this case, the user must manually allow the permission.

ACTIVITY_RECOGNITION_PERMISSION_DENIED → const ErrorCodes

Occurs when activity recognition permission is denied.

ACTIVITY_RECOGNITION_PERMISSION_PERMANENTLY_DENIED → const ErrorCodes

Occurs when activity recognition permission is permanently denied. In this case, the user must manually allow the permission.

Properties

hashCode → int
The hash code for this object.
no setterinherited
index → int
A numeric identifier for the enumerated value.
no setterinherited
name → String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

values → const List<ErrorCodes>
A constant List of the values in this enum, in order of their declaration.